@@ -1,8 +1,8 @@
-from tweetl.get_tweets import GetTweet
-from tweetl.cleansing_tweets import CleansingTweets
+from Tweetl.get_tweets import GetTweet
+from Tweetl.cleansing_tweets import CleansingTweets
 
 __copyright__    = 'Copyright (C) 2020 deepblue'
-__version__      = '0.0.4'
+__version__      = '0.0.7'
 __license__      = 'MIT'
 __author__       = 'deepblue'
 __author_email__ = 'main@deepbluets.page'
